#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-server
version:              1.1.2.1
visibility:           public
id:                   snap-server-1.1.2.1-5PTNmoxshwELs4XYJtgPlF
key:                  snap-server-1.1.2.1-5PTNmoxshwELs4XYJtgPlF
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  184fc648b826b145e56938c1ec96ab85
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-server
hs-libraries:         HSsnap-server-1.1.2.1-5PTNmoxshwELs4XYJtgPlF
depends:
    attoparsec-0.14.4-JfqiEkfNFnE8n0O4G6WZl6 base-4.18.2.1
    blaze-builder-0.4.4.1-FEj65wWpaUs60ShEedjm3y bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3KPQ2ag2hyl5eroFFm5hRO
    clock-0.8.4-KVaAxYiBG7fJzRmSi3lEWo containers-0.6.7
    filepath-1.4.300.1 io-streams-1.5.2.2-Dd6n5yqwWQWLI8pGaNDCZh
    io-streams-haproxy-1.0.1.0-8t7D7YgS3C7KgHQOq51NEY
    lifted-base-0.2.3.12-3eDINyaMLEgBGrTitrtp7s mtl-2.3.1
    network-3.1.4.0-5wCX3hTprFv2vYcKA8r7kN
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    snap-core-1.0.5.1-HvFo0lJYuK0LLa5xX7dv6o text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-1ix4vuxXmr9HJAwOQozvAF
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

